#include <stdio.h>
#include <stdlib.h>

#define ArraySize 1000

typedef char DataType;
typedef struct LinkNode
{
    DataType data; struct LinkNode *next;
} LinkNode;
typedef struct { 
    LinkNode *top; int cnt;
} LinkStack;

LinkStack stack;

void InitStack(LinkStack *stack);
void ClearStack(LinkStack *stack);
int IsEmpty(LinkStack *stack);
void Push(LinkStack *stack, DataType data);
DataType Top(LinkStack *stack);
DataType Pop(LinkStack *stack);
LinkNode *CreateNode(DataType data);
void DestroyNode(LinkNode *node);
void InsertAfterPtr(LinkNode *ptr, LinkNode *node);
void DeleteNextPtr(LinkNode *ptr);

void InitStack(LinkStack *stack)
{
    DataType data = 0;
    stack->top = CreateNode(data);
    stack->cnt = 0;
}

void ClearStack(LinkStack *stack)
{
    while (!IsEmpty(stack)) Pop(stack);
}

int IsEmpty(LinkStack *stack)
{
    return (stack->top->next == NULL);
}

void Push(LinkStack *stack, DataType data)
{
    LinkNode *node = CreateNode(data);
    if (node == NULL) { printf("overflow\n"); exit(-1); }
    else { InsertAfterPtr(stack->top, node); stack->cnt++; }
}

DataType Top(LinkStack *stack)
{
    if (IsEmpty(stack)) { printf("underflow\n"); exit(-1); } 
    else { return stack->top->next->data; }
}

DataType Pop(LinkStack *stack) {
    DataType ret = Top(stack);
    DeleteNextPtr(stack->top);
    stack->cnt--;
    return ret;
}

LinkNode *CreateNode(DataType data)
{
  LinkNode *node;

  node = (LinkNode *)malloc(sizeof(LinkNode));
  node->data = data;
  node->next = NULL;

  return node;
}

void DestroyNode(LinkNode *node)
{
  //注意：若结构体中的数据域是由动态内存分配产生的，也应释放其内存空间
  free(node);
}

void InsertAfterPtr(LinkNode *ptr, LinkNode *node)
{
    LinkNode *next = ptr->next;
 
    node->next = next;
    ptr->next = node;
}

void DeleteNextPtr(LinkNode *ptr)
{
    LinkNode *next = ptr->next;
    LinkNode *next_next = (next != NULL ? next->next : NULL);

    if (next != NULL) 
    {  
       ptr->next = next_next; 
       DestroyNode(next); 
    }
}

int main()
{
    char ch, result[ArraySize];
    int i, cnt = 0;

    InitStack(&stack);				//初始化栈

    while ((ch = getchar()) != EOF)
    {
        if (ch == '#') break;		//编辑结束
        else if (ch == '*') 		//清空栈
            ClearStack(&stack);
        else if (ch == '?')			//出栈
            Pop(&stack);
        else
            Push(&stack, ch);		//入栈
    }

     while (!IsEmpty(&stack)) 
        result[cnt++] = Pop(&stack);

    for (i = cnt-1; i >= 0; i--) 
      printf("%c", result[i]);

    ClearStack(&stack);     //清空栈
}