#include <stdio.h>
#include <stdlib.h>

typedef int DataType;
typedef struct Node 
{
    DataType data;
    struct Node *next, *prev;
} LinkNode;

LinkNode *head;

LinkNode *CreateNode(DataType data);
void DestroyNode(LinkNode *node);
void Initialize(LinkNode **head);
void Finalize(LinkNode *head);
void InsertAfterPtr(LinkNode *ptr, LinkNode *node);
void DeleteCurrPtr(LinkNode *ptr);

LinkNode *CreateNode(DataType data)
{
  LinkNode *node;

  node = (LinkNode *)malloc(sizeof(LinkNode));
  node->data = data;
  node->next = NULL;

  return node;
}

void DestroyNode(LinkNode *node)
{
  //注意：若结构体中的数据域是由动态内存分配产生的，也应释放其内存空间
  free(node);
}

void Initialize(LinkNode **head)
{
    DataType data = 0;
    *head = CreateNode(data);
}

void Finalize(LinkNode *head)
{
    LinkNode *iter, *tmp;

    iter = head;

    while (iter != NULL)
    {
        tmp = iter;
        iter = iter->next;
        DestroyNode(tmp);
    }

}

void InsertAfterPtr(LinkNode *ptr, LinkNode *node)
{
    LinkNode *next = ptr->next;

    node->prev = ptr; 
    node->next = next;

    ptr->next = node;
    if (next != NULL) next->prev = node;
}

void DeleteCurrPtr(LinkNode *ptr)
{
    LinkNode *prev = ptr->prev;
    LinkNode *next = ptr->next;

    if (prev != NULL) prev->next = next;
    if (next != NULL) next->prev = prev;

    DestroyNode(ptr);
}

int main() {
  int N, M, i;
  LinkNode *ptr, *node, *tmp;
  
  scanf("%d %d", &N, &M);

  Initialize(&head); //初始化链表


  ptr = head;
  for (i = 1; i <= N; i++) //尾插法构造链表，结点编号1-N
  {
    node = CreateNode(i);
    InsertAfterPtr(ptr, node);
    ptr = node;
  }

  tmp = head;
  while (head->next->next != NULL)//直到链表中仅有一个元素
  {
    ptr = tmp;

    for (i = 1; i <= M; i++)   //数M个数
    {
      tmp = ptr;
      ptr = ptr->next;
      //如果到达链表末尾，则重新回到开头
      if (ptr == NULL) ptr = head->next; 
    }

    DeleteCurrPtr(ptr); //删除结点
  }

  printf("%d\n", head->next->data);

  Finalize(head); //清理链表
}