#include <stdio.h>
#include <stdlib.h>

typedef int DataType;
typedef struct LinkNode
{
    DataType data; struct LinkNode *next;
} LinkNode;
typedef struct
{
    LinkNode *front, *rear; int cnt;
} LinkQueue;
LinkQueue queue;

void InitQueue(LinkQueue *queue);
void ClearQueue(LinkQueue *queue);
int IsEmpty(LinkQueue *queue);
void Enqueue(LinkQueue *queue, DataType data);
DataType Front(LinkQueue *queue);
DataType Dequeue(LinkQueue *queue);
LinkNode *CreateNode(DataType data);
void DestroyNode(LinkNode *node);
void InsertAfterPtr(LinkNode *ptr, LinkNode *node);
void DeleteNextPtr(LinkNode *ptr);

void InitQueue(LinkQueue *queue)
{
    DataType data = 0;
    queue->front = queue->rear = CreateNode(data);
    queue->cnt = 0;
}

void ClearQueue(LinkQueue *queue)
{
    while (!IsEmpty(queue)) Dequeue(queue);
}

int IsEmpty(LinkQueue *queue)
{
    return (queue->front == queue->rear);
}

void Enqueue(LinkQueue *queue, DataType data)
{
    LinkNode *node = CreateNode(data);
    if (node == NULL) { printf("overflow\n"); exit(-1); }
    else { InsertAfterPtr(queue->rear, node); queue->rear = node; queue->cnt++; }
}

DataType Front(LinkQueue *queue)
{
    if (IsEmpty(queue)) { printf("underflow\n"); exit(-1); }
    else { return queue->front->next->data; }
}

DataType Dequeue(LinkQueue *queue)
{
    DataType ret = Front(queue);
    if (queue->front->next == queue->rear) queue->rear = queue->front; //临界情况
    DeleteNextPtr(queue->front);
    queue->cnt--;
    return ret;
}

LinkNode *CreateNode(DataType data)
{
  LinkNode *node;

  node = (LinkNode *)malloc(sizeof(LinkNode));
  node->data = data;
  node->next = NULL;

  return node;
}

void DestroyNode(LinkNode *node)
{
  //注意：若结构体中的数据域是由动态内存分配产生的，也应释放其内存空间
  free(node);
}

void InsertAfterPtr(LinkNode *ptr, LinkNode *node)
{
    LinkNode *next = ptr->next;
 
    node->next = next;
    ptr->next = node;
}

void DeleteNextPtr(LinkNode *ptr)
{
    LinkNode *next = ptr->next;
    LinkNode *next_next = (next != NULL ? next->next : NULL);

    if (next != NULL) 
    {  
       ptr->next = next_next; 
       DestroyNode(next); 
    }
}



int main() {
    int n, m, i, t;
    DataType x;

    scanf("%d %d", &n, &m);

    InitQueue(&queue);

    for (i = 1; i <= n; i++) {
        scanf("%d", &t);
        Enqueue(&queue, t);

        while (!IsEmpty(&queue))
        {   //队头元素不在[t-m, t]范围内就出队 
            x = Front(&queue);
            if (x < t - m) Dequeue(&queue);
            else break;
        }

        printf("%d ", queue.cnt);
    }

    ClearQueue(&queue);
}